half_circle_scroll library
A customizable Flutter package that provides a half-circle scrollable widget with smooth animations and multiple orientation options.
This package includes:
- HalfCircleScroll - The main widget
- HalfCircleScrollConfig - Configuration class for customization
- HalfCircleScrollItem - Data model for items
- HalfCircleOrientation - Enum for orientation options
- HalfCircleItemShape - Enum for item shapes
Classes
- HalfCircleScroll
- A customizable half circle scroll widget
- HalfCircleScrollConfig
- Configuration class for styling the half circle scroll
- HalfCircleScrollItem
- Represents the data for a single item in the circular scroll view.
- ResponsiveArcPainter
- Responsive arc painter
- ResponsiveCircularItem
- Responsive circular item widget
Enums
- HalfCircleItemShape
- Enum to define the shape of items
- HalfCircleOrientation
- Enum to define the orientation of the half circle
Typedefs
- HalfCircleItemBuilder = Widget Function(BuildContext context, int index, HalfCircleScrollItem item, bool isSelected, double scale, double opacity)
- Custom widget builder for items